%% Create simple line plot
% Plot the height of a ball falling in gravity over 5 seconds

t = 0:5; % time
y = 100 - 0.5*9.8*t.^2; % initial height of 100 m

% plot(t, y) % standard plot
plot(x, y, 'r--^') % plot with a dashed red line and triangle data markers

%% Annotate the plot

xlabel('x [s]')
ylabel('t [m]')
title('Distance versus Time')

%% Create 3d plot

figure(2) % create a new figure window

% define a helix
t = 0:.05:20;
x = cos(t);
y = sin(t);
z = .2*t;

plot3(x, y, z) % plot the helix


%% Add animation
% Let's say we want to animate a bead sliding along the helix.
% The first thing that comes to mind would be to plot the position of the
% bead at every time.  We'll try that and see what happens.

hold on; % makes sure figure doesn't erase, this would also save any
    % annotations you make from being wiped out

for i = 1:length(t) % loop over time steps
    % plot the position of the bead at each time step with a red ball
    plot3(x(i), y(i), z(i), 'ro', 'MarkerSize', 8, 'MarkerFaceColor', 'r');
    drawnow % this tells matlab to draw the figure now
%     pause(.01) % you can also tell matlab to wait for a specific amount of time 
        % to plot, this can adjust the speed of animation
end

hold off; % turn the hold off

% This isn't exactly what we wanted since each position of the bead is
% shown.  Let's think about this a little harder.

%% Redraw figure every time
% one thing to try is to re-draw the plot every time

% reset figure and draw helix
figure(2)
clf % clear the figure

for i = 1:length(t)
    plot3(x, y, z) % plot the helix
        % Since this is outside of a hold command, it will wipe out any
        % data that was previously plotted.
    hold on;
    % plot the point at position i
    plot3(x(i), y(i), z(i), 'ro', 'MarkerSize', 8, 'MarkerFaceColor', 'r');
    hold off;
    drawnow
end

% This works, but it's not the most efficient way to do things.
% If we were plotting a lot of things, Matlab would run much more slowly
% than it could if we put a bit more thought into things.

%% Using figure handles
% The solution to this is to use figure handles

% Reset figure and draw helix
figure(2)
clf
plot3(x, y, z) % plot the helix

hold on; % makes sure figure doesn't erase

% Here h is the handle to the figure
h = plot3(x(1), y(1), z(1), 'ro', 'MarkerSize', 8, 'MarkerFaceColor', 'r');

% Use get(h) to see all the different properties of the figure that you can
% view and set.  There are a bunch of things, but you'll never need to
% adjust 90% of these.

for i = 2:length(t)
    % Set the x, y, and z data of the bead to the next point along the helix
    set(h, 'XData', x(i), 'YData', y(i), 'ZData', z(i));
    drawnow
%     pause
end

hold off

% This does what we want, and Matlab will run smoothly
